@@ -1,7 +1,7 @@
 /*=============================================================================
 *
 *   WCSLIB - an implementation of the FITS WCS proposal.
-*   Copyright (C) 1995, Mark Calabretta
+*   Copyright (C) 1995,1996 Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU Library General Public License as published
@@ -50,7 +50,8 @@
 *   anything other than a predefined magic value.
 *
 *   Given:
-*      pcode[4] char     WCS projection code (see below).
+*      pcode[4] const char
+*                        WCS projection code (see below).
 *
 *   Given and returned:
 *      cel      celprm*  Spherical coordinate transformation parameters
@@ -71,8 +72,10 @@
 *   coordinates (lng,lat).
 *
 *   Given:
-*      pcode[4] char     WCS projection code (see below).
-*      lng,lat  double   Celestial longitude and latitude of the projected
+*      pcode[4] const char
+*                        WCS projection code (see below).
+*      lng,lat  const double
+*                        Celestial longitude and latitude of the projected
 *                        point, in degrees.
 *
 *   Given and returned:
@@ -103,8 +106,10 @@
 *   coordinates (x,y).
 *
 *   Given:
-*      pcode[4] char     WCS projection code (see below).
-*      x,y      double   Projected coordinates, "degrees".
+*      pcode[4] const char
+*                        WCS projection code (see below).
+*      x,y      const double
+*                        Projected coordinates, "degrees".
 *
 *   Given and returned:
 *      prj      prjprm*  Projection parameters (usage is described in the
@@ -226,16 +231,35 @@
 *      TSC: tangential spherical cube
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: cel.c,v 2.1 1995/11/09 03:09:49 mcalabre Exp $
+*   $Id: cel.c,v 2.3 1996/05/24 07:25:36 mcalabre Exp $
 *===========================================================================*/
 
 #include "cel.h"
 
-#ifndef __STDC__
-#ifndef const
-#define const
-#endif
-#endif
+int  npcode = 25;
+char pcodes[25][4] =
+      {"AZP", "TAN", "SIN", "STG", "ARC", "ZPN", "ZEA", "AIR", "CYP", "CAR",
+       "MER", "CEA", "COP", "COD", "COE", "COO", "BON", "PCO", "GLS", "PAR",
+       "AIT", "MOL", "CSC", "QSC", "TSC"};
+
+/* Map error number to error message for each function. */
+const char *celset_errmsg[] = {
+   0,
+   "Invalid coordinate transformation parameters",
+   "Ill-conditioned coordinate transformation parameters"};
+
+const char *celfwd_errmsg[] = {
+   0,
+   "Invalid coordinate transformation parameters",
+   "Invalid projection parameters",
+   "Invalid value of (lng,lat)"};
+
+const char *celrev_errmsg[] = {
+   0,
+   "Invalid coordinate transformation parameters",
+   "Invalid projection parameters",
+   "Invalid value of (x,y)"};
+ 
 
 #ifdef SIGNBIT
 #define signbit(X) ((X) < 0.0 ? 0 : 1)
@@ -243,7 +267,7 @@
 
 int celset(pcode, cel, prj)
 
-char pcode[4];
+const char pcode[4];
 struct celprm *cel;
 struct prjprm *prj;
 
@@ -492,8 +516,8 @@ struct prjprm *prj;
 
 int celfwd(pcode, lng, lat, cel, phi, theta, prj, x, y)
 
-char   pcode[4];
-double lng, lat;
+const char pcode[4];
+const double lng, lat;
 struct celprm *cel;
 double *phi, *theta;
 struct prjprm *prj;
@@ -521,8 +545,8 @@ double *x, *y;
 
 int celrev(pcode, x, y, prj, phi, theta, cel, lng, lat)
 
-char   pcode[4];
-double x, y;
+const char pcode[4];
+const double x, y;
 struct prjprm *prj;
 double *phi, *theta;
 struct celprm *cel;
